<?php

declare(strict_types = 1);

namespace Drupal\Tests\schemadotorg_starterkit_events\Functional;

use Drupal\Tests\schemadotorg\Functional\SchemaDotOrgBrowserTestBase;

/**
 * Tests the functionality of the Schema.org Starter Kit: Events module.
 *
 * @group schemadotorg_starterkit_events
 */
class SchemaDotOrgStarterKitEventsTest extends SchemaDotOrgBrowserTestBase {

  // phpcs:disable
  /**
   * Disabled config schema checking.
   */
  protected $strictConfigSchema = FALSE;
  // phpcs:enable

  /**
   * Modules to install.
   *
   * @var string[]
   */
  protected static $modules = ['schemadotorg_starterkit_events'];

  /**
   * Test Schema.org Starter Kit: Events.
   */
  public function testEvents(): void {
    /** @var \Drupal\Core\Config\Entity\ConfigEntityStorageInterface $node_type_storage */
    $node_type_storage = \Drupal::entityTypeManager()->getStorage('node_type');
    /** @var \Drupal\node\NodeTypeInterface $node_type */
    $node_type = $node_type_storage->load('event');

    // Check that the event node type was created.
    $this->assertNotNull($node_type);

    // Check that the node.type.event.yml was rewritten as expected.
    $this->assertEquals(['module' => ['menu_ui']], $node_type->getDependencies());
    $this->assertEquals([], $node_type->getThirdPartySetting('menu_ui', 'available_menus'));
    $this->assertFalse($node_type->get('display_submitted'));

    // Check that Schema.org mappings were created.
    /** @var \Drupal\schemadotorg\SchemaDotOrgMappingStorageInterface $mapping_storage */
    $mapping_storage = \Drupal::entityTypeManager()->getStorage('schemadotorg_mapping');
    $this->assertNotNull($mapping_storage->load('node.event'));

    // Check that the events view configuration was imported.
    // @see schemadotorg_preinstall_test/config/optional/views.view.events.yml
    /** @var \Drupal\schemadotorg\SchemaDotOrgMappingStorageInterface $mapping_storage */
    $view_storage = \Drupal::entityTypeManager()->getStorage('view');
    $this->assertNotNull($view_storage->load('events'));

    // Check event properties/fields.
    /** @var \Drupal\schemadotorg\SchemaDotOrgMappingInterface $mapping */
    $mapping = $mapping_storage->load('node.event');
    $expected_properties = [
      'body' => 'description',
      'schema_event_schedule' => 'eventSchedule',
      'langcode' => 'inLanguage',
      'title' => 'name',
    ];
    $this->assertEquals($expected_properties, $mapping->getSchemaProperties());
  }

}
